@@ -2,7 +2,7 @@ package X3D::Components::Core::ChildNode;
 
 our $VERSION = '0.002';
 
-use X3D 'X3DChildNode : X3DNode { 
+use X3D::Package 'X3DChildNode : X3DNode { 
   SFNode [in,out] metadata NULL [X3DMetadataObject]
 }';
 
