@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFDouble;
 
 our $VERSION = '0.009';
 
-use X3D 'MFDouble : X3DArrayField { [] }';
+use X3D::Package 'MFDouble : X3DArrayField { [] }';
 
 1;
 __END__
