@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFFloat;
 
 our $VERSION = '0.009';
 
-use X3D 'MFFloat : MFDouble { [] }';
+use X3D::Package 'MFFloat : MFDouble { [] }';
 
 1;
 __END__
