@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFInt32;
 
 our $VERSION = '0.009';
 
-use X3D 'MFInt32 : X3DArrayField { [] }';
+use X3D::Package 'MFInt32 : X3DArrayField { [] }';
 
 1;
 __END__
