@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFTime;
 
 our $VERSION = '0.009';
 
-use X3D 'MFTime : X3DArrayField { [] }';
+use X3D::Package 'MFTime : X3DArrayField { [] }';
 
 1;
 __END__
