@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFVec2d;
 
 our $VERSION = '0.009';
 
-use X3D 'MFVec2d : X3DArrayField { [] }';
+use X3D::Package 'MFVec2d : X3DArrayField { [] }';
 
 1;
 __END__
