@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFVec2f;
 
 our $VERSION = '0.009';
 
-use X3D 'MFVec2f : MFVec2d { [] }';
+use X3D::Package 'MFVec2f : MFVec2d { [] }';
 
 1;
 __END__
