@@ -2,7 +2,7 @@ package X3D::FieldTypes::MFVec3f;
 
 our $VERSION = '0.009';
 
-use X3D 'MFVec3f : MFVec3d { [] }';
+use X3D::Package 'MFVec3f : MFVec3d { [] }';
 
 1;
 __END__
