@@ -2,7 +2,7 @@ package X3D::FieldTypes::SFFloat;
 
 our $VERSION = '0.01';
 
-use X3D 'SFFloat : SFDouble { 0 }';
+use X3D::Package 'SFFloat : SFDouble { 0 }';
 
 use base 'X3D::BaseFieldTypes::Scalar';
 
