@@ -2,7 +2,7 @@ package X3D::FieldTypes::SFTime;
 
 our $VERSION = '0.009';
 
-use X3D 'SFTime : SFDouble { 0 }';
+use X3D::Package 'SFTime : SFDouble { 0 }';
 
 1;
 __END__
