@@ -2,7 +2,7 @@ package X3D::FieldTypes::SFVec2f;
 
 our $VERSION = '0.009';
 
-use X3D 'SFVec2f : SFVec2d { 0 0 }';
+use X3D::Package 'SFVec2f : SFVec2d { 0 0 }';
 
 1;
 __END__
