@@ -2,7 +2,7 @@ package X3D::FieldTypes::SFVec3f;
 
 our $VERSION = '0.009';
 
-use X3D 'SFVec3f : SFVec3d { 0 0 0 }';
+use X3D::Package 'SFVec3f : SFVec3d { 0 0 0 }';
 
 1;
 __END__
