@@ -2,7 +2,7 @@ package X3D::ParentHash;
 
 our $VERSION = '0.011';
 
-use X3D 'X3DParentHash : X3DHash {}';
+use X3D::Package 'X3DParentHash : X3DHash {}';
 
 use X3D::Tie::WeakHash;
 
@@ -11,23 +11,25 @@ use overload
   ;
 
 sub new {
-	my $self = $_[0];
-	my $type = ref($self) || $self;
-	return bless X3D::Tie::WeakHash->new, $type;
+   my $self = $_[0];
+   my $type = ref($self) || $self;
+   return bless new X3D::Tie::WeakHash, $type;
 }
 
-sub getValues { new X3DArray [ grep { $_ } values( %{ $_[0] } ) ] }
+sub getValues {
+   new X3D::Array( [ grep { $_ } values( %{ $_[0] } ) ] );
+}
 
 sub add {
-	my $this = shift;
-	$this->{ $_[0]->getId } = $_[0] if defined $_[0];
-	return;
+   my $this = shift;
+   $this->{ $_[0]->getId } = $_[0] if defined $_[0];
+   return;
 }
 
 sub remove {
-	my $this = shift;
-	delete $this->{ $_[0]->getId };
-	return;
+   my $this = shift;
+   delete $this->{ $_[0]->getId };
+   return;
 }
 
 1;
