@@ -1,5 +1,5 @@
 package X3D::Tie::Value::BaseNodeArray;
-use X3D;
+use X3D::Perl;
 
 our $VERSION = '0.009';
 
@@ -39,6 +39,10 @@ sub removeParents {
 			$node->getParents->remove( $this->getParent );
 		}
 	}
+	
+	foreach my $node ( grep { $_ } @_ ) {
+		$node->dispose;
+	}
 }
 
 sub TIEARRAY {
